#!/bin/sh
set -eu

# version_greater A B returns whether A > B
version_greater() {
    [ "$(printf '%s\n' "$@" | sort -t '.' -n -k1,1 -k2,2 -k3,3 | head -n 1)" != "$1" ]
}

image_version="${MAUTIC_VERSION}"

if [ -f /data/config/version ]; then
  installed_version="$(awk '$1' /data/config/version)"
 
  if version_greater "$installed_version" "$image_version"; then
    echo "Can't start Mautic because the version of the data ($installed_version) is higher than the docker image version ($image_version) and downgrading is not supported. Are you sure you have pulled the newest image version?"
    exit 1
  fi

  if version_greater "$image_version" "$installed_version"; then
    echo "Upgrading mautic from $installed_version ..."
    php /usr/src/mautic/app/console mautic:update:apply --no-interaction
    echo ${MAUTIC_VERSION} > /data/config/version
  else
    echo "Initializing mautic $image_version ..."
  fi
else 
  echo "New mautic instance"
  echo "starting mautic installation"
  echo "Creating folder structure, you should mount /data as a volume if you want to persist your install" 
  mkdir -p /data/cache/prod /data/config /data/themes /data/idp /data/media/files /data/media/images /data/plugins

  php /makedb.php "$MAUTIC_DB_HOST" "$MAUTIC_DB_USER" "$MAUTIC_DB_PASSWORD" "$MAUTIC_DB_NAME"
  php /usr/src/mautic/app/console mautic:install:data --no-interaction --force
  echo ${MAUTIC_VERSION} > /data/config/version
  chown -R www-data:www-data /data
fi
    
exec "$@"
